#[non_exhaustive]pub enum CommitmentPlan {
Unspecified,
Flex,
FlexFlatRate,
Trial,
Monthly,
MonthlyFlatRate,
Annual,
AnnualFlatRate,
ThreeYear,
None,
UnknownValue(UnknownValue),
}Expand description
Commitment plan defines the current committed period. Capacity commitment cannot be deleted during it’s committed period.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Invalid plan value. Requests with this value will be rejected with
error code google.rpc.Code.INVALID_ARGUMENT.
Flex
Flex commitments have committed period of 1 minute after becoming ACTIVE. After that, they are not in a committed period anymore and can be removed any time.
FlexFlatRate
Same as FLEX, should only be used if flat-rate commitments are still available.
Trial
Trial commitments have a committed period of 182 days after becoming
ACTIVE. After that, they are converted to a new commitment based on the
renewal_plan. Default renewal_plan for Trial commitment is Flex so
that it can be deleted right after committed period ends.
Monthly
Monthly commitments have a committed period of 30 days after becoming ACTIVE. After that, they are not in a committed period anymore and can be removed any time.
MonthlyFlatRate
Same as MONTHLY, should only be used if flat-rate commitments are still available.
Annual
Annual commitments have a committed period of 365 days after becoming ACTIVE. After that they are converted to a new commitment based on the renewal_plan.
AnnualFlatRate
Same as ANNUAL, should only be used if flat-rate commitments are still available.
ThreeYear
3-year commitments have a committed period of 1095(3 * 365) days after becoming ACTIVE. After that they are converted to a new commitment based on the renewal_plan.
None
Should only be used for renewal_plan and is only meaningful if
edition is specified to values other than EDITION_UNSPECIFIED. Otherwise
CreateCapacityCommitmentRequest or UpdateCapacityCommitmentRequest will
be rejected with error code google.rpc.Code.INVALID_ARGUMENT. If the
renewal_plan is NONE, capacity commitment will be removed at the end of
its commitment period.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using CommitmentPlan::value or CommitmentPlan::name.
Implementations