FailoverMode

Enum FailoverMode 

#[non_exhaustive]
pub enum FailoverMode { Unspecified, Soft, Hard, UnknownValue(UnknownValue), }
The failover mode when a user initiates a failover on a reservation determines how writes that are pending replication are handled after the failover is initiated.

Working with unknown values

This enum is defined as #[non_exhaustive] because Google Cloud may add additional enum variants at any time. Adding new variants is not considered a breaking change. Applications should write their code in anticipation of:

  • New values appearing in future releases of the client library, and
  • New values received dynamically, without application changes.

Please consult the Working with enums section in the user guide for some guidelines.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unspecified

Invalid value.



Soft

When customers initiate a soft failover, BigQuery will wait until all committed writes are replicated to the secondary. This mode requires both regions to be available for the failover to succeed and prevents data loss.



Hard

When customers initiate a hard failover, BigQuery will not wait until all committed writes are replicated to the secondary. There can be data loss for hard failover.



UnknownValue(UnknownValue)

If set, the enum was initialized with an unknown value.

Applications can examine the value using FailoverMode::value or FailoverMode::name.

Implementations

Source

impl FailoverMode

pub fn value(&self) -> Option<i32>

Gets the enum value.

Returns None if the enum contains an unknown value deserialized from the string representation of enums.

pub fn name(&self) -> Option<&str>

Gets the enum value as a string.

Returns None if the enum contains an unknown value deserialized from the integer representation of enums.