CreateAssignmentRequest

Struct CreateAssignmentRequest 

#[non_exhaustive]
pub struct CreateAssignmentRequest { pub parent: String, pub assignment: Option<Assignment>, pub assignment_id: String, /* private fields */ }
The request for ReservationService.CreateAssignment. Note: “bigquery.reservationAssignments.create” permission is required on the related assignee.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. The parent resource name of the assignment E.g. projects/myproject/locations/US/reservations/team1-prod

assignment: Option<Assignment>

Assignment resource to create.

assignment_id: String

The optional assignment ID. Assignment name will be generated automatically if this field is empty. This field must only contain lower case alphanumeric characters or dashes. Max length is 64 characters.

Implementations

Source

impl CreateAssignmentRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = CreateAssignmentRequest::new().set_parent(format!("projects/{project_id}/locations/{location_id}/reservations/{reservation_id}"));
pub fn set_assignment<T>(self, v: T) -> Self
where T: Into<Assignment>,

Sets the value of assignment.

Example
use google_cloud_bigquery_reservation_v1::model::Assignment;
let x = CreateAssignmentRequest::new().set_assignment(Assignment::default()/* use setters */);
pub fn set_or_clear_assignment<T>(self, v: Option<T>) -> Self
where T: Into<Assignment>,

Sets or clears the value of assignment.

Example
use google_cloud_bigquery_reservation_v1::model::Assignment;
let x = CreateAssignmentRequest::new().set_or_clear_assignment(Some(Assignment::default()/* use setters */));
let x = CreateAssignmentRequest::new().set_or_clear_assignment(None::<Assignment>);
pub fn set_assignment_id<T: Into<String>>(self, v: T) -> Self

Sets the value of assignment_id.

Example
let x = CreateAssignmentRequest::new().set_assignment_id("example");