#[non_exhaustive]pub struct DeleteCapacityCommitmentRequest {
pub name: String,
pub force: bool,
/* private fields */
}Expand description
The request for ReservationService.DeleteCapacityCommitment.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. Resource name of the capacity commitment to delete. E.g.,
projects/myproject/locations/US/capacityCommitments/123
force: boolCan be used to force delete commitments even if assignments exist. Deleting commitments with assignments may cause queries to fail if they no longer have access to slots.
Implementations