MergeCapacityCommitmentsRequest

Struct MergeCapacityCommitmentsRequest 

#[non_exhaustive]
pub struct MergeCapacityCommitmentsRequest { pub parent: String, pub capacity_commitment_ids: Vec<String>, pub capacity_commitment_id: String, /* private fields */ }
Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Parent resource that identifies admin project and location e.g., projects/myproject/locations/us

capacity_commitment_ids: Vec<String>

Ids of capacity commitments to merge. These capacity commitments must exist under admin project and location specified in the parent. ID is the last portion of capacity commitment name e.g., ‘abc’ for projects/myproject/locations/US/capacityCommitments/abc

capacity_commitment_id: String

Optional. The optional resulting capacity commitment ID. Capacity commitment name will be generated automatically if this field is empty. This field must only contain lower case alphanumeric characters or dashes. The first and last character cannot be a dash. Max length is 64 characters.

Implementations

Source

impl MergeCapacityCommitmentsRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = MergeCapacityCommitmentsRequest::new().set_parent(format!("projects/{project_id}/locations/{location_id}"));
pub fn set_capacity_commitment_ids<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of capacity_commitment_ids.

Example
let x = MergeCapacityCommitmentsRequest::new().set_capacity_commitment_ids(["a", "b", "c"]);
pub fn set_capacity_commitment_id<T: Into<String>>(self, v: T) -> Self

Sets the value of capacity_commitment_id.

Example
let x = MergeCapacityCommitmentsRequest::new().set_capacity_commitment_id("example");