#[non_exhaustive]pub struct MoveAssignmentRequest {
pub name: String,
pub destination_id: String,
pub assignment_id: String,
/* private fields */
}Expand description
The request for ReservationService.MoveAssignment.
Note: “bigquery.reservationAssignments.create” permission is required on the destination_id.
Note: “bigquery.reservationAssignments.create” and “bigquery.reservationAssignments.delete” permission are required on the related assignee.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name of the assignment,
e.g.
projects/myproject/locations/US/reservations/team1-prod/assignments/123
destination_id: StringThe new reservation ID, e.g.:
projects/myotherproject/locations/US/reservations/team2-prod
assignment_id: StringThe optional assignment ID. A new assignment name is generated if this field is empty.
This field can contain only lowercase alphanumeric characters or dashes. Max length is 64 characters.
Implementations
Sourceimpl MoveAssignmentRequest
impl MoveAssignmentRequest
Sourcepub fn set_destination_id<T: Into<String>>(self, v: T) -> Self
pub fn set_destination_id<T: Into<String>>(self, v: T) -> Self
Sets the value of destination_id.
Example
ⓘ
let x = MoveAssignmentRequest::new().set_destination_id(format!("projects/{project_id}/locations/{location_id}/reservations/{reservation_id}"));Sourcepub fn set_assignment_id<T: Into<String>>(self, v: T) -> Self
pub fn set_assignment_id<T: Into<String>>(self, v: T) -> Self
Sets the value of assignment_id.
Example
ⓘ
let x = MoveAssignmentRequest::new().set_assignment_id("example");Trait Implementations
Sourceimpl Clone for MoveAssignmentRequest
impl Clone for MoveAssignmentRequest
Sourcefn clone(&self) -> MoveAssignmentRequest
fn clone(&self) -> MoveAssignmentRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MoveAssignmentRequest
impl Debug for MoveAssignmentRequest
Sourceimpl Default for MoveAssignmentRequest
impl Default for MoveAssignmentRequest
Sourcefn default() -> MoveAssignmentRequest
fn default() -> MoveAssignmentRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for MoveAssignmentRequest
impl Message for MoveAssignmentRequest
Sourceimpl PartialEq for MoveAssignmentRequest
impl PartialEq for MoveAssignmentRequest
impl StructuralPartialEq for MoveAssignmentRequest