#[non_exhaustive]pub struct MergeCapacityCommitmentsRequest {
pub parent: String,
pub capacity_commitment_ids: Vec<String>,
pub capacity_commitment_id: String,
/* private fields */
}Expand description
The request for ReservationService.MergeCapacityCommitments.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringParent resource that identifies admin project and location e.g.,
projects/myproject/locations/us
capacity_commitment_ids: Vec<String>Ids of capacity commitments to merge. These capacity commitments must exist under admin project and location specified in the parent. ID is the last portion of capacity commitment name e.g., ‘abc’ for projects/myproject/locations/US/capacityCommitments/abc
capacity_commitment_id: StringOptional. The optional resulting capacity commitment ID. Capacity commitment name will be generated automatically if this field is empty. This field must only contain lower case alphanumeric characters or dashes. The first and last character cannot be a dash. Max length is 64 characters.
Implementations
Sourceimpl MergeCapacityCommitmentsRequest
impl MergeCapacityCommitmentsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_capacity_commitment_ids<T, V>(self, v: T) -> Self
pub fn set_capacity_commitment_ids<T, V>(self, v: T) -> Self
Sets the value of capacity_commitment_ids.
Example
let x = MergeCapacityCommitmentsRequest::new().set_capacity_commitment_ids(["a", "b", "c"]);Sourcepub fn set_capacity_commitment_id<T: Into<String>>(self, v: T) -> Self
pub fn set_capacity_commitment_id<T: Into<String>>(self, v: T) -> Self
Sets the value of capacity_commitment_id.
Example
let x = MergeCapacityCommitmentsRequest::new().set_capacity_commitment_id("example");Trait Implementations
Sourceimpl Clone for MergeCapacityCommitmentsRequest
impl Clone for MergeCapacityCommitmentsRequest
Sourcefn clone(&self) -> MergeCapacityCommitmentsRequest
fn clone(&self) -> MergeCapacityCommitmentsRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more